aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/functions_user.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2017-02-22 11:09:02 +0100
committerMarc Alexander <admin@m-a-styles.de>2017-02-22 11:09:02 +0100
commitdbf7f2b7eee993c4d7df38abad1f917928694c7d (patch)
tree7480c6189bf6784d9aa6b70f7bb6f89dccc9b5bd /phpBB/includes/functions_user.php
parenta302fb47a82618b03ae909cacf3c7db852feb217 (diff)
parent4c3ddea09fa7975dec5180eff6d6947fb41e619a (diff)
downloadforums-dbf7f2b7eee993c4d7df38abad1f917928694c7d.tar
forums-dbf7f2b7eee993c4d7df38abad1f917928694c7d.tar.gz
forums-dbf7f2b7eee993c4d7df38abad1f917928694c7d.tar.bz2
forums-dbf7f2b7eee993c4d7df38abad1f917928694c7d.tar.xz
forums-dbf7f2b7eee993c4d7df38abad1f917928694c7d.zip
Merge branch '3.1.x' into 3.2.x
Diffstat (limited to 'phpBB/includes/functions_user.php')
-rw-r--r--phpBB/includes/functions_user.php10
1 files changed, 6 insertions, 4 deletions
diff --git a/phpBB/includes/functions_user.php b/phpBB/includes/functions_user.php
index ed69264980..3dd4b3c2e5 100644
--- a/phpBB/includes/functions_user.php
+++ b/phpBB/includes/functions_user.php
@@ -272,13 +272,15 @@ function user_add($user_row, $cp_data = false, $notifications_data = null)
* Use this event to modify the values to be inserted when a user is added
*
* @event core.user_add_modify_data
* @var array user_row Array of user details submited to user_add
* @var array cp_data Array of Custom profile fields submited to user_add
* @var array sql_ary Array of data to be inserted when a user is added
* @since 3.1.0-a1
* @changed 3.1.0-b5 Added user_row and cp_data
+ * @changed 3.1.11-RC1 Added notifications_data
*/
- $vars = array('user_row', 'cp_data', 'sql_ary');
+ $vars = array('user_row', 'cp_data', 'sql_ary', 'notifications_data');
extract($phpbb_dispatcher->trigger_event('core.user_add_modify_data', compact($vars)));
$sql = 'INSERT INTO ' . USERS_TABLE . ' ' . $db->sql_build_array('INSERT', $sql_ary);
@@ -272,13 +272,15 @@ function user_add($user_row, $cp_data = false, $notifications_data = null)
*
* @event core.user_add_modify_data
- * @var array user_row Array of user details submited to user_add
- * @var array cp_data Array of Custom profile fields submited to user_add
- * @var array sql_ary Array of data to be inserted when a user is added
+ * @var array user_row Array of user details submited to user_add
+ * @var array cp_data Array of Custom profile fields submited to user_add
+ * @var array sql_ary Array of data to be inserted when a user is added
+ * @var array notifications_data Array of notification data to be inserted when a user is added
* @since 3.1.0-a1
* @changed 3.1.0-b5 Added user_row and cp_data